local Addon = Apollo.GetAddon("ClearNameplates")

local ti = table.insert
local format = string.format

local function findUnit(units, unit)
    for _,unitEl in pairs(units) do
        if unitEl:GetId() == unit:GetId() then
            return unitEl
        end
    end
    return nil
end

function Addon:RadarOnUnitCreated(unit)
    if not unit then return end

    if unit:GetType() ~= "Player" then return end

    -- already known
    if findUnit(self.scanResults, unit) then return end

    ti(self.scanResults, unit)
end

function Addon:RadarOnUnitDestroyed(unit)
    local unitId = unit:GetId()

    self.scanResults[unitId] = nil

    -- My character got destroyed
    if self.me and self.me:GetId() == unitId then
        self.me = nil
        return
    end

end

function Addon:RadarScan()
    if not self.me then return end

    if #self.scanResults < 1 then return end

    if not self.radarWindow:IsValid() then return end

    local distanceTo = Addon.distanceToUnit

    table.sort(self.scanResults, function(a, b) return distanceTo(a, self.me) < distanceTo(b, self.me) end)

    local wasPvp = false
    local text = { "\n" }
    for unitId, unit in pairs(self.scanResults) do

        repeat

            if not unit:IsValid() then break end
            if unit:GetId() == self.me:GetId() then break end

            local pvp = unit:IsPvpFlagged()
            local hostile = unit:GetDispositionTo(self.me) == Unit.CodeEnumDisposition.Hostile

            --            if not hostile then break end

            local npInfo = self.nameplates[unit:GetId()]
            local onscreen = npInfo and npInfo.window and not npInfo.window:IsOccluded()

            if not wasPvp and pvp then wasPvp = true end

            local distance = distanceTo(unit, self.me)
            if distance > 1000 then distance = -1 end

            ti(text, format([[<P TextColor="ff%s" Font="Courier">%s%2d %4s %4d %s %s </P>]],
                (hostile and pvp and self.hostilePlayerPvpColor)
                        or (hostile and self.hostilePlayerNotpvpColor)
                        or self.friendlyPlayerColor,
                onscreen and ">" or " ",
                unit:GetLevel() or -1,
                self.classById[unit:GetClassId()]:sub(1, 4) or "????", -- bug
                distance,
                (pvp and "x") or " ",
                unit:GetName()
            ))

        until true

    end

    self.radarWindow:SetText(table.concat(text))

    --    if wasPvp then self.radarWindow:Show(true) end

end
