local Addon = Apollo.GetAddon("ClearNameplates")

local onoff = function(b) return b and "on" or "off" end
local info = function(s) Print(string.format("cnp: %s", s)) end

function Addon:OnCnpCommand(selfcmd, args)
    local matches = string.gmatch(args, "%S+")
    local cmd = matches()
    local arg = matches()

    if not cmd then
        info([[usage of /cnp command:
        /cnp fontsize <7,9,10,11,12,14,16>
        /cnp pvpon <color>
        /cnp pvpoff <color>
        /cnp hostile <color>
        /cnp friendly <color>
        /cnp neutral <color>
        /cnp reset
        /cnp radar
        /cnp alt
        /cnp altcolor <color>
        /cnp altsize <7,9,10,11,12,14,16>

        where <color> is a hex rgb value, like ffffff is white.]])
        return
    end

    if cmd == "reset" then
        self:resetSettings()
        self:wpClear()
        self:destroyNpWindows()
        return
    end

    if cmd == "radar" then
        local newState = not self.radarWindow:IsShown()
        self.radarWindow:Show(newState)
        self.radarEnabled = newState
        return
    end

    if cmd == "alt" then
        self.altUnitText = not self.altUnitText
        self:wpClear()
        self:destroyNpWindows()
        info(string.format("alt mode is now %s", onoff(self.altUnitText)))
        return
    end

    if not arg then
        info("missing argument")
        return
    end

    local validSize = function(size)
        return size and (size >= 7 and size <= 16) and (size ~= 8 and size ~= 13 and size ~= 15)
    end

    if cmd == "fontsize" then
        local newsize = tonumber(arg)
        if validSize(newsize) then
            self.fontSize = newsize
            for _,npInfo in pairs(self.nameplates) do
                if npInfo.window then npInfo.window:SetFont(string.format("CRB_Interface%d_BBO", newsize)) end
            end
        else
            info("given font size is invalid")
        end
        return
    end

    if cmd == "altsize" then
        local newsize = tonumber(arg)
        if validSize(newsize) then
            self.altHealthFontSize = arg;
        else
            info("given font size is invalid")
        end
        return
    end

    if cmd == "pvpon" then self.hostilePlayerPvpColor = arg; return; end
    if cmd == "pvpoff" then self.hostilePlayerNotpvpColor = arg; return; end
    if cmd == "hostile" then self.hostileColor = arg; return; end
    if cmd == "friendly" then self.friendlyColor = arg; return; end
    if cmd == "neutral" then self.neutralColor = arg; return; end
    if cmd == "altcolor" then self.altHealthColor = arg; return; end

    info(string.format("unknown command `%s'", cmd))
end
